@@ -48,10 +48,9 @@ impl Name {
 
     /// Resolve a name from the text of token.
     fn resolve(raw_text: &str) -> Name {
-        if let Some(text) = raw_text.strip_prefix("r#") {
-            Name::new_text(SmolStr::new(text))
-        } else {
-            Name::new_text(raw_text.into())
+        match raw_text.strip_prefix("r#") {
+            Some(text) => Name::new_text(SmolStr::new(text)),
+            None => Name::new_text(raw_text.into()),
         }
     }
 
@@ -200,6 +199,7 @@ pub mod known {
         Range,
         Neg,
         Not,
+        None,
         Index,
         // Components of known path (function name)
         filter_map,
@@ -210,6 +210,7 @@ pub mod known {
         // Builtin macros
         file,
         column,
+        const_format_args,
         compile_error,
         line,
         module_path,
@@ -249,40 +250,68 @@ pub mod known {
         test_case,
         // Safe intrinsics
         abort,
-        size_of,
-        min_align_of,
-        needs_drop,
-        caller_location,
-        size_of_val,
-        min_align_of_val,
         add_with_overflow,
-        sub_with_overflow,
-        mul_with_overflow,
-        wrapping_add,
-        wrapping_sub,
-        wrapping_mul,
-        saturating_add,
-        saturating_sub,
-        rotate_left,
-        rotate_right,
-        ctpop,
-        ctlz,
-        cttz,
-        bswap,
         bitreverse,
+        bswap,
+        caller_location,
+        ctlz,
+        ctpop,
+        cttz,
         discriminant_value,
-        type_id,
+        forget,
         likely,
-        unlikely,
-        ptr_guaranteed_eq,
-        ptr_guaranteed_ne,
+        maxnumf32,
+        maxnumf64,
+        min_align_of_val,
+        min_align_of,
         minnumf32,
         minnumf64,
-        maxnumf32,
+        mul_with_overflow,
+        needs_drop,
+        ptr_guaranteed_eq,
+        ptr_guaranteed_ne,
+        rotate_left,
+        rotate_right,
         rustc_peek,
-        maxnumf64,
+        saturating_add,
+        saturating_sub,
+        size_of_val,
+        size_of,
+        sub_with_overflow,
+        type_id,
         type_name,
+        unlikely,
         variant_count,
+        wrapping_add,
+        wrapping_mul,
+        wrapping_sub,
+        // known methods of lang items
+        add,
+        mul,
+        sub,
+        div,
+        rem,
+        shl,
+        shr,
+        bitxor,
+        bitor,
+        bitand,
+        add_assign,
+        mul_assign,
+        sub_assign,
+        div_assign,
+        rem_assign,
+        shl_assign,
+        shr_assign,
+        bitxor_assign,
+        bitor_assign,
+        bitand_assign,
+        eq,
+        ne,
+        ge,
+        gt,
+        le,
+        lt,
     );
 
     // self/Self cannot be used as an identifier
